@@ -61,15 +61,15 @@ pub fn gen_decoder(enum_name: &Ident, variants: &[Variant], atom_defs: &Tokens,
     }).collect();
 
     quote! {
-        impl<'a> ::rustler::NifDecoder<'a> for #enum_type {
-            fn decode(term: ::rustler::NifTerm<'a>) -> Result<Self, ::rustler::NifError> {
+        impl<'a> ::rustler::Decoder<'a> for #enum_type {
+            fn decode(term: ::rustler::Term<'a>) -> Result<Self, ::rustler::Error> {
                 #atom_defs
 
-                let value = ::rustler::types::atom::NifAtom::from_term(term)?;
+                let value = ::rustler::types::atom::Atom::from_term(term)?;
 
                 #(#variant_defs)*
 
-                Err(::rustler::NifError::Atom("invalid_variant"))
+                Err(::rustler::Error::Atom("invalid_variant"))
             }
         }
     }
@@ -93,8 +93,8 @@ pub fn gen_encoder(enum_name: &Ident, variants: &[Variant], atom_defs: &Tokens,
     }).collect();
 
     quote! {
-        impl<'b> ::rustler::NifEncoder for #enum_type {
-            fn encode<'a>(&self, env: ::rustler::NifEnv<'a>) -> ::rustler::NifTerm<'a> {
+        impl<'b> ::rustler::Encoder for #enum_type {
+            fn encode<'a>(&self, env: ::rustler::Env<'a>) -> ::rustler::Term<'a> {
                 #atom_defs
 
                 match *self {
